<template>
  <div>
    <ht-input
      class="quick-search"
      v-model='input'
      placeholder='请输入科目编码搜索'
      @keyup.enter.native='quickSearch'
    >
      <el-button
        slot="append"
        icon="el-icon-search"
        @click="quickSearch"
      ></el-button>
    </ht-input>
    <el-divider direction="vertical"></el-divider>
    <el-button
      size="small"
      type="primary"
      icon="el-icon-plus"
      style="margin-left:15px;margin-right:15px"
      @click="handleAdd"
      v-methodauth='"courseDetails_add"'
    >添加</el-button>
    <el-popconfirm
      title="这是一段内容确定删除吗？"
      @onConfirm='handleDelete'
    >
      <el-button
        type='danger'
        slot="reference"
        icon='el-icon-delete'
        v-methodauth='"courseDetails_remove"'
      >删除</el-button>
    </el-popconfirm>
    <el-table
      :data="tableData"
      class='table'
      row-key="id"
      :max-height='clientHeight'
      border
      lazy
      :load="load"
      v-loading='loading'
      @selection-change="handleSelectionChange"
      @row-dblclick='handleEdit'
      :tree-props="{children: 'children', hasChildren: 'hasChildren'}"
    >
      <el-table-column type="selection">
      </el-table-column>
      <el-table-column
        prop="subjectCode"
        label="科目编码"
        align="center"
      >
      </el-table-column>
      <el-table-column
        prop="subjectName"
        label="科目名称"
        align="center"
      >
      </el-table-column>
      <el-table-column
        prop="companyName"
        align="center"
        label="所属公司名称"
      >
      </el-table-column>
      <el-table-column
        align="center"
        label="操作"
      >
        <template slot-scope="scope">
          <el-button
            icon='el-icon-plus'
            @click='handleChildren(scope)'
          >添加下级</el-button>
        </template>
      </el-table-column>
    </el-table>
    <!-- 分页 -->
    <!-- <el-pagination
      @size-change="handleSizeChange"
      @current-change="handleCurrentChange"
      :current-page="pageBean.page"
      :page-sizes="[10, 50, 100, 200]"
      :page-size="20"
      layout="total, sizes, prev, pager, next, jumper"
      :total="pageBean.total"
      style='position: absolute;right: 25px;bottom: 25px;'
    >
    </el-pagination> -->
    <!-- 弹出框 -->
    <el-dialog
      :title="type === 'add' ? '【成本科目】添加' : '【成本科目】修改'"
      :visible.sync="dialogVisible"
      width="600px"
      :before-close="handleClose"
      :close-on-click-modal='false'
    >
      <el-form
        ref='form'
        v-form
        :model="form"
        :rules='rules'
        label-width="80px"
        v-if='dialogVisible'
      >
        <el-row>
          <!-- <el-col :span='12'>
            <el-form-item
              label="父级ID"
              prop="pcode"
            >
              <el-input
                v-model="form.pcode"
                placeholder="父级ID"
              ></el-input>
            </el-form-item>
          </el-col> -->
          <el-col :span='24'>
            <el-form-item
              label="科目编码"
              prop="subjectCode"
            >
              <el-input
                v-model="form.subjectCode"
                placeholder="科目编码"
              ></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span='24'>
            <el-form-item
              label="科目名称"
              prop="subjectName"
            >
              <el-input
                v-model="form.subjectName"
                placeholder="科目名称"
              ></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="24">
            <el-form-item
              label="所属公司"
              prop="companyName"
            >

              <!-- <eip-org-selector
                v-model="form.companyName"
                :permission="permission"
                :single="true"
                append-to-body
                :config="{id:'form.companyId', name: 'form.companyName'}"
                placeholder="请选择"
              /> -->
              <company-info-selector
                v-model='form.companyName'
                :valueName='form.companyIds'
                @handleChanged='handleChanged'
                @value='companyValue'
              />

            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <span
        slot="footer"
        class="dialog-footer"
      >
        <el-button @click="handleCancel">取 消</el-button>
        <el-button
          type="primary"
          @click="handleSubmit"
        >保存</el-button>
      </span>
      <!-- <el-dialog
        :visible.sync="loadingDialogVisible"
        v-loading="loading"
        element-loading-text="拼命加载中"
        element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(0, 0, 0, 0.8)"
      ></el-dialog> -->
    </el-dialog>
  </div>
</template>
<script>
import req from '@/request.js'
import basicData from '@/api/basicData.js'
import eipOrgSelector from '@/components/eipControl/selector/EipOrgSelector.vue'
import companyInfoSelector from '@/components/selector/companyInfoSelector.vue'
export default {
  inject:['reload'],
  name: 'CostAccountManagement',
  components: {
    // eipOrgSelector,
    companyInfoSelector
  },
  data() {
    return {
      tableData: [],
      childrenTablData: [],
      dialogVisible: false,
      pageBean: {
        page: 1,
        pageSize: 20,
        total: 0
      },
      //判断是否是添加还是修改
      type: '',
      form: {
        pcode: 'root',
        pname: 'root',
        companyName: ''
      },
      permission: 'b',
      rules: {
        subjectCode: {
          required: true,
          message: '请输入科目编码',
          trigger: 'blur'
        },
        companyName: {
          required: true,
          message: '请选择所属公司',
          trigger: 'blur'
        },
        subjectName: {
          required: true,
          message: '请输入科目名称',
          trigger: 'blur'
        },
        pcode: {
          required: true,
          message: '请输入科目名称',
          trigger: 'blur'
        }
      },
      ids: [],
      clientHeight: '',
      isChild: false, //是否是添加下级
      loading: false, //加载
      loadingDialogVisible: false,
      input: '',
      maps: new Map(), //运用于数据懒加载数据实时刷新
      parentId: '', //懒加载时的父级id
      currentId: '' //当前id
    }
  },
  created() {
    this.getCostAccount('root')
    this.getHeight()
  },
  methods: {
    getHeight() {
      this.clientHeight = document.body.clientHeight - 180
      //  console.log(this.clientHeight)
    },
    //搜索
    quickSearch() {
      const params = {
        pageBean: {
          page: 1,
          pageSize: 20,
          showTotal: true
        },
        params: {},
        querys: [
          {
            group: 'main',
            operation: 'EQUAL',
            parentGroup: '',
            property: 'subjectCode',
            relation: 'AND',
            value: this.input
          }
        ],
        sorter: []
      }
      if (this.input) {
        basicData.searchCostAccountManagement(params).then(res => {
          this.tableData = res.data
        })
      } else {
        this.getCostAccount('root')
      }
    },
    //获取数据
    getCostAccount(query) {
      basicData.getCostAccountManagement(query).then(res => {
        res.data.forEach(item => {
          if (item.hasChildren === 'false') {
            item.hasChildren = false
          }
        })
        this.tableData = res.data
        this.pageBean = {
          page: res.page,
          pageSize: res.pageSize,
          total: res.total
        }
      })
    },
    load(tree, treeNode, resolve) {
      // console.log(tree, treeNode, resolve)
      this.parentId = tree.id
      const id = tree.id
      this.maps.set(id, {tree, treeNode, resolve})
      basicData.getCostAccountManagement(tree.subjectCode).then(res => {
        res.data.forEach(item => {
          if (item.hasChildren === 'false') {
            item.hasChildren = false
          }
        })
        this.childrenTablData = res.data
        // console.log(res.data, this.childrenTablData, '33')
      })
      setTimeout(() => {
        resolve(this.childrenTablData)
      }, 1000)
    },
    //新增
    handleAdd() {
      this.dialogVisible = true
      this.type = 'add'
    },
    //修改
    handleEdit(data) {
      // console.log(data)
      let form = {
        companyName: ''
      }
      this.type = 'edit'
      this.dialogVisible = true
      this.form = {...form, ...data}
    },
    handleClose(done) {
      //清空表单
      // this.form = {companyName: '', companyId: ''}
      this.form = {
        companyName: ''
      }
      done()
    },
    //取消弹窗
    handleCancel() {
      //清空表单
      // this.form = {companyName: '', companyId: ''}
      this.form = {
        companyName: ''
      }
      this.dialogVisible = false
    },
    //提交保存或者修改
    handleSubmit() {
      //验证表单是否填写完
      this.$refs.form.validate(bool => {
        if (bool) {
          this.dialogVisible = false
          this.loading = true
          //请求保存提交
          //默认情况下添加为root
          if (this.type == 'add') {
            if (!this.isChild) {
              this.form.pcode = 'root'
              this.form.pname = 'root'
            }
          }
          // console.log(this.form, '提交')
          basicData.addCostAccountManagement(this.form).then(res => {
            this.$message.success(res.message)
            this.getCostAccount('root') //重新获取数据
            if (this.parentId) {
              const {tree, treeNode, resolve} = this.maps.get(this.parentId)
              this.load(tree, treeNode, resolve)
            }
            this.form = {
              companyName: ''
            }
            this.isChild = false
            this.loading = false
          })
        }
      })
    },
    //复选框事件
    handleSelectionChange(rows) {
      // console.log(rows)
      rows.forEach(item => {
        this.ids.push(item.id)
      })
    },
    //去重
    unique(arr) {
      for (var i = 0; i < arr.length; i++) {
        for (var j = i + 1; j < arr.length; j++) {
          if (arr[i] == arr[j]) {
            //第一个等同于第二个，splice方法删除第二个
            arr.splice(j, 1)
            j--
          }
        }
      }
      return arr
    },
    //删除
    handleDelete() {
      this.loading = true
      const ids = this.unique(this.ids)
      const strs = ids.join(',')
      basicData.deleteCostAccountManagement(strs).then(res => {
        this.getCostAccount('root')
        //删除重新渲染界面，多删无法使用懒加载函数,使用页面刷新
        this.reload()
        this.loading = false
      })
    },
    // 分页
    handleSizeChange(val) {
      // console.log(val, '分页的一页多少条数据')
      this.pageBean.pageSize = val
    },
    handleCurrentChange(val) {
      // console.log(val, '分页选中的那一页')
      this.pageBean.page = val
    },
    //添加下级
    handleChildren(row) {
      // console.log(row,'ffff')
      this.type = 'add'
      this.dialogVisible = true
      this.isChild = true
      this.form.pcode = row.row.subjectCode
      this.form.pname = row.row.subjectName
      // console.log(row)
    },
    //公司赋值
    handleChanged(obj) {
      // console.log(obj.valueInfo.join(','))
      this.form.companyIds = JSON.stringify(obj.valueInfo)
      this.form.companyName = obj.name
      this.form.companyId = obj.id
    },
    companyValue(obj) {
      // console.log(obj)
      this.form.companyName = obj.name
      this.form.companyId = obj.id
      this.form.companyIds = JSON.stringify(obj.id.split(' ')) //必须是空格
    }
  }
}
</script>
<style lang="scss" scoped>
.fullheight {
  padding: 20px;
}
.quick-search {
  width: 400px;
  margin-right: 20px;
}
.table {
  width: 100%;
  margin-top: 10px;
}
/deep/ .has-gutter {
  tr {
    th {
      background-color: #eee !important;
      border: 1px solid #fff !important;
      border-top: none !important;
      & > .cell {
        font-family: Microsoft YaHei;
        font-size: 14px;
        font-weight: 700;
        color: #3c4353;
      }
    }
  }
}
/deep/ .el-table {
  .cell {
    font-size: 14px;
    color: #606266;
  }
}
/deep/ .el-dialog__header {
  border-right: 1px solid #103c5d;
}
//弹出层居中
/deep/ .el-dialog {
  display: flex;
  flex-direction: column;
  margin: 0 !important;
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
}
/deep/ .el-dialog .el-dialog__body {
  flex: 1;
  overflow: auto;
}
</style>